@@ -90,7 +90,10 @@ class OWImageGrid(widget.OWWidget):
     auto_commit = settings.Setting(True)
 
     class Warning(OWWidget.Warning):
-        incompatible_subset = Msg("Data subset is incompatible with Data")
+        incompatible_subset = Msg(
+            "No Data Subset elements appear in the Data.")
+        extras_in_subset = Msg(
+            "Some Data Subset elements do not appear in the Data.")
         no_valid_data = Msg("No valid data")
 
     def __init__(self):
@@ -100,7 +103,7 @@ class OWImageGrid(widget.OWWidget):
 
         self.data = None
         self.data_subset = None
-        self.subset_indices = []
+        self.data_is_subset = None
         self.nonempty = []
 
         self.allAttrs = []
@@ -328,28 +331,36 @@ class OWImageGrid(widget.OWWidget):
                 self.update_selection()
 
     def handleNewSignals(self):
-        self.Warning.incompatible_subset.clear()
-        self.subset_indices = []
-
-        if self.data and self.data_subset and len(self.stringAttrs) > 0:
-            transformed = self.data_subset.transform(self.data.domain)
-            attr = self.stringAttrs[self.imageAttr]
-
-            # for the subset we need to check if it contains the image
-            # attribute, if all indices from the subset are in the original
-            # array, and if same image on the same index
-            data_indices = [e.id for e in self.data]
-            if attr in self.data_subset.domain \
-                and all(row.id in data_indices and self.data[np.where(
-                    data_indices == row.id)[0][0], attr] == row[attr]
-                        for row in transformed):
-                indices = {e.id for e in transformed}
-
-                self.subset_indices = [ex.id in indices for ex in self.data]
-            else:
-                self.Warning.incompatible_subset()
+        self.data_is_subset = self._update_data_is_subset()
         self.apply_subset()
 
+    def _update_data_is_subset(self):
+        self.Warning.incompatible_subset.clear()
+        self.Warning.extras_in_subset.clear()
+        if not (self.data and self.data_subset):
+            return None
+
+        subset_ids = set(self.data_subset.ids)
+        data_is_subset = np.array([id_ in subset_ids for id_ in self.data.ids])
+
+        if len(self.stringAttrs) > 0:
+            attr = self.stringAttrs[self.imageAttr]
+            data_names_col = self.data.get_column(attr)
+            try:
+                subset_names = set(self.data_subset.get_column(attr))
+            except ValueError:
+                # feature can not be found; checking if the domain includes it
+                # could be insufficient if it was a computed feature
+                pass
+            else:
+                data_is_subset |= [dn in subset_names for dn in data_names_col]
+
+        nsub = np.sum(data_is_subset)
+        if nsub < len(self.data_subset):
+            self.Warning.incompatible_subset(shown=nsub == 0)
+            self.Warning.extras_in_subset(shown=nsub != 0)
+        return data_is_subset
+
     def cancel_all_futures(self):
         for item in self.items:
             if item.future is not None:
@@ -404,10 +415,10 @@ class OWImageGrid(widget.OWWidget):
 
     def apply_subset(self):
         if self.image_grid:
-            subset_indices = (self.subset_indices if self.subset_indices
-                else [True] * len(self.items))
+            is_subset = (self.data_is_subset if self.data_is_subset is not None
+                         else np.ones(len(self.items), dtype=bool))
             ordered_subset_indices = self.image_grid.order_to_grid(
-                subset_indices)
+                is_subset)
 
             for item, in_subset in zip(self.items, ordered_subset_indices):
                 item.widget.setSubset(in_subset)
