@@ -35,17 +35,14 @@ from Orange.widgets.utils.filedialogs import RecentPath
 from Orange.widgets.utils.concurrent import (
     ThreadExecutor, FutureWatcher, methodinvoke
 )
+from Orange.widgets.utils.localization import pl
 
-try:
-    from orangecanvas.preview.previewbrowser import TextLabel
-except ImportError:
-    from Orange.canvas.preview.previewbrowser import TextLabel
+from orangecanvas.preview.previewbrowser import TextLabel
 
 from Orange.widgets.utils.signals import Output
 
 from orangecontrib.imageanalytics.import_images import ImportImages
 
-
 def prettyfypath(path):
     home = os.path.expanduser("~/")
     if path.startswith(home):  # case sensitivity!
@@ -307,11 +304,11 @@ class OWImportImages(widget.OWWidget):
             ncategories = self._n_image_categories
             n_skipped = self._n_skipped
             if ncategories < 2:
-                text = "{} image{}".format(nvalid, "s" if nvalid != 1 else "")
+                text = f'{nvalid} {pl(nvalid, "image")}'
             else:
-                text = "{} images / {} categories".format(nvalid, ncategories)
+                text = f'{nvalid} {pl(nvalid, "image")} / {ncategories} {pl(ncategories, "category")}'
             if n_skipped > 0:
-                text = text + ", {} skipped".format(n_skipped)
+                text = text + f', {n_skipped} skipped'
         elif self.__state == State.Cancelled:
             text = "Cancelled"
         elif self.__state == State.Error:
