@@ -466,8 +466,7 @@ def column_data_as_qurl(
 def column_data_as_str(
         table: Orange.data.Table, var: Orange.data.Variable
 ) -> Sequence[str]:
-    var = table.domain[var]
-    data, _ = table.get_column_view(var)
+    data = table.get_column(var)
     return list(map(var.str_val, data))
 
 
@@ -524,7 +523,10 @@ def loader_qnam(
             QNetworkRequest.CacheLoadControlAttribute,
             QNetworkRequest.PreferCache
         )
-        request.setAttribute(QNetworkRequest.FollowRedirectsAttribute, True)
+        request.setAttribute(
+            QNetworkRequest.RedirectPolicyAttribute,
+            QNetworkRequest.NoLessSafeRedirectPolicy
+        )
         request.setMaximumRedirectsAllowed(5)
         if hasattr(QNetworkRequest, "setTransferTimeout"):
             request.setTransferTimeout()
